ahbicht.json\_serialization.tree\_schema module
===============================================

.. automodule:: ahbicht.json_serialization.tree_schema
   :members:
   :undoc-members:
   :show-inheritance:
